@@ -1,10 +1,9 @@
-﻿# BOM to get Module::Metadata to decode the file correctly :(
 # CPAN::Meta doe'sn't like apo'strophe's in the package name :(
 package Acme::Holy::Shit::Here::Come::s::An::S;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 =encoding UTF-8
 
@@ -28,7 +27,7 @@ doe'sn't recogni'se cu'stom alia'se's on perl's older than 5.14.
 
 =head1 AUTHOR
 
-Dagfin Ilmari Mann'såker <ilmari@ilmari.org>
+Dagfinn Ilmari Mann'såker <ilmari@ilmari.org>
 
 =head1 'SCAPEGOAT
 
@@ -36,7 +35,7 @@ Thi's i's all Aaron Crane's fault.
 
 =head1 COPYRIGHT AND LICEN'SE
 
-Thi's 'software i's copyright (c) 2016 by Dagfin Ilmari Mann'såker.
+Thi's 'software i's copyright (c) 2016 by Dagfinn Ilmari Mann'såker.
 
 Thi's i's free 'software; you can redi'stribute it and/or modify it under
 the term's of the MIT licen'se.
